Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2926)

Unified Diff: chrome/browser/ui/views/infobars/confirm_infobar.cc

Issue 2375543003: Add SetProminent() to MdTextButton to create blue buttons. (Closed)
Patch Set: Fix nits. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/infobars/confirm_infobar.cc
diff --git a/chrome/browser/ui/views/infobars/confirm_infobar.cc b/chrome/browser/ui/views/infobars/confirm_infobar.cc
index f462b806e3624a8beb7ee986ca7602bc9b948ce9..53376070955a4d937dac4284fa6e04c446340dd4 100644
--- a/chrome/browser/ui/views/infobars/confirm_infobar.cc
+++ b/chrome/browser/ui/views/infobars/confirm_infobar.cc
@@ -74,7 +74,7 @@ void ConfirmInfoBar::ViewHierarchyChanged(
if (delegate->GetButtons() & ConfirmInfoBarDelegate::BUTTON_OK) {
ok_button_ = views::MdTextButton::Create(
this, delegate->GetButtonLabel(ConfirmInfoBarDelegate::BUTTON_OK));
- ok_button_->SetCallToAction(true);
+ ok_button_->SetProminent(true);
if (delegate->OKButtonTriggersUACPrompt()) {
elevation_icon_setter_.reset(new ElevationIconSetter(
ok_button_,
@@ -89,8 +89,8 @@ void ConfirmInfoBar::ViewHierarchyChanged(
this,
delegate->GetButtonLabel(ConfirmInfoBarDelegate::BUTTON_CANCEL));
if (delegate->GetButtons() == ConfirmInfoBarDelegate::BUTTON_CANCEL) {
- // Apply CTA only if the cancel button is the only button.
- cancel_button_->SetCallToAction(true);
+ // Apply prominent styling only if the cancel button is the only button.
+ cancel_button_->SetProminent(true);
} else {
// Otherwise set the bg color to white and the text color to black.
// TODO(estade): These should be removed and moved into the native
« no previous file with comments | « chrome/browser/ui/libgtk2ui/native_theme_gtk2.cc ('k') | chrome/browser/ui/views/location_bar/bubble_icon_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698